@@ -6,6 +6,7 @@ HistoryWindow::HistoryWindow(QWidget *parent) :
     QMainWindow(parent)
 {
     setAttribute(Qt::WA_Maemo5StackedWindow);
+    setAttribute(Qt::WA_Maemo5PortraitOrientation);
     setWindowTitle("History");
 
     dh = new DayHistory(this);
@@ -19,6 +20,14 @@ HistoryWindow::HistoryWindow(QWidget *parent) :
     setCentralWidget(lstDates);
 }
 
+void HistoryWindow::changeEvent(QEvent *event)
+{
+    if(event->type() == QEvent::ActivationChange)
+    {
+        load();
+    }
+}
+
 void HistoryWindow::showExercises(QModelIndex index)
 {
     dh->load(index.data().toString());
