@@ -118,7 +118,10 @@ void NewExerciseWindow::saveExercise()
     else
     {
         qDebug () << "save new exercise 4";
-        xml->saveEx(name,group,muscle,info);
+        if(oldName == name)
+            xml->saveEx(name,group,muscle,info);
+        else
+            xml->saveEx(oldName,group,muscle,info,name);
     }
     //if saved OK
     if(pic1 != "")
@@ -169,7 +172,8 @@ void NewExerciseWindow::load()
 
 void NewExerciseWindow::load(QString name, QString group, QString muscle, QString info)
 {
-    txtName->setEnabled(false);
+    oldName = name;
+    //txtName->setEnabled(false);
     txtName->setText(name);
     txtMuscle->setText(muscle);
     btnGroup->setValueText(group);
