@@ -13,8 +13,7 @@ WeightDialog::WeightDialog(QWidget *parent) :
     //setWindowFlags(this->windowFlags() | Qt::Window);
     setWindowTitle("Save weight");
 
-    hLayout = new QHBoxLayout();
-    buttonLayout = new QVBoxLayout();
+    vLayout = new QVBoxLayout();
     qDebug () << "WeightDialog::WeightDialog 2";
     modelReps = new QStandardItemModel(this);
     for (int i = 1; i <= 25; i++)
@@ -35,9 +34,9 @@ WeightDialog::WeightDialog(QWidget *parent) :
 
     btnVar->setPickSelector(selectorVar);
 
-    buttonLayout->addWidget(btnReps);
-    buttonLayout->addWidget(btnVar);
-    hLayout->addLayout(buttonLayout);
+    vLayout->addWidget(btnReps);
+    vLayout->addWidget(btnVar);
+
 
     qDebug () << "WeightDialog::WeightDialog 5";
 
@@ -45,23 +44,22 @@ WeightDialog::WeightDialog(QWidget *parent) :
     radioOK = new QRadioButton("Perfect");
     radioHard = new QRadioButton("Hard");
 
-    QVBoxLayout *vLayout = new QVBoxLayout();
-    vLayout->addWidget(radioEasy);
-    vLayout->addWidget(radioOK);
-    vLayout->addWidget(radioHard);
-    hLayout->addLayout(vLayout);
+    QHBoxLayout *hLayout = new QHBoxLayout();
+    hLayout->addWidget(radioEasy);
+    hLayout->addWidget(radioOK);
+    hLayout->addWidget(radioHard);
+    vLayout->addLayout(hLayout);
 
     btnSave = new QPushButton("Save");
 
-    hLayout->addWidget(btnSave);
+    vLayout->addWidget(btnSave);
 
-    setLayout(hLayout);
+    setLayout(vLayout);
     xml = new XML();
     //load();
     qDebug () << "WeightDialog::WeightDialog 6";
     connect(btnSave, SIGNAL(clicked()),this,SLOT(save()));
     qDebug () << "WeightDialog::WeightDialog 7";
-    resize(480,350);
 }
 
 void WeightDialog::load(QString name, QString grp, QString currentSet)
@@ -106,8 +104,7 @@ void WeightDialog::load(QString name, QString grp, QString currentSet)
 
 void WeightDialog::loadCardio(QString name, QString m, QString s)
 {
-    buttonLayout->removeWidget(btnReps);
-    btnReps->setText("");
+    vLayout->removeWidget(btnReps);
     //btnReps->setEnabled(false);
     btnVar->setText("Distance");
     QList <QString> list;
@@ -130,7 +127,7 @@ void WeightDialog::loadCardio(QString name, QString m, QString s)
     list = xml->getHistoryByExercise(name);
     if(!list.isEmpty())
         btnVar->setValueText(list.takeFirst());
-
+    this->update();
 }
 
 void WeightDialog::save()
